@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 #
 #  __init__.py
-"""
+r"""
 Extensions to :mod:`sphinx.ext.autosummary`.
 
 Provides an enhanced version of https://autodocsumm.readthedocs.io/
@@ -13,7 +13,7 @@ configuration value, or via :confval:`autodocsumm_member_order`.
 Also patches :class:`sphinx.ext.autosummary.Autosummary` to fix an issue where
 the module name is sometimes duplicated.
 I.e. ``foo.bar.baz()`` became ``foo.bar.foo.bar.baz()``, which of course doesn't exist
-and so resulted in a broken link.
+and created a broken link..
 
 
 .. versionadded:: 0.7.0
@@ -24,6 +24,9 @@ and so resulted in a broken link.
 	falling back to :class:`~sphinx.ext.autodoc.DataDocumenter`.
 
 
+.. latex:vspace:: -10px
+
+
 Configuration
 --------------
 
@@ -41,8 +44,15 @@ This applies not only to :rst:dir:`automodule` etc. directives,
 but also to :rst:dir:`automodulesumm` etc. directives.
 
 
+.. latex:vspace:: -10px
+
+
 API Reference
 ----------------
+
+
+.. latex:vspace:: -10px
+
 """
 #
 #  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -129,14 +139,24 @@ def add_autosummary(self):
 	sourcename = self.get_sourcename()
 	grouped_documenters = self.get_grouped_documenters()
 
+	if not self.options.get("autosummary-no-titles", False) and grouped_documenters:
+		content.blankline()
+		content.append(".. latex:vspace:: 10px")
+		content.blankline()
+
 	for section, documenters in grouped_documenters.items():
 		if not self.options.get("autosummary-no-titles", False):
 			content.append(f"**{section}:**")
+			content.blankline()
+			content.append(".. latex:vspace:: -5px")
 
 		content.blankline(ensure_single=True)
 
+		# TODO transform to make caption associated with table in LaTeX
+
 		content.append(".. autosummary::")
 		content.blankline(ensure_single=True)
+		content.blankline(ensure_single=True)
 
 		member_order = get_first_matching(
 				lambda x: x != "groupwise",
@@ -166,7 +186,7 @@ class PatchedAutosummary(Autosummary):
 	the module name is sometimes duplicated.
 
 	I.e. ``foo.bar.baz()`` became ``foo.bar.foo.bar.baz()``, which of course doesn't exist
-	and so resulted in a broken link.
+	and created a broken link.
 
 	.. versionadded:: 0.5.1
 	.. versionchanged:: 0.7.0  Moved from :mod:`sphinx_toolbox.patched_autosummary`.
@@ -205,6 +225,10 @@ class PatchedAutosummary(Autosummary):
 
 			Now selects the appropriate documenter for attributes rather than
 			falling back to :class:`~sphinx.ext.autodoc.DataDocumenter`.
+
+		:rtype:
+
+		.. clearpage::
 		"""
 
 		doccls = get_documenter(app, obj, parent)
